from setuptools import setup

setup(name='jb_probablity',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['jb_probablity'],
      author= 'Jay Bagrecha',
      zip_safe=False)
